@@ -40,11 +40,12 @@ def combine(in_files, out_file, verbose=False, replace = None):
     isCSS = False
     combined = ""
 
-    if len(in_files) > 0 and __get_ext(in_files[0]) in ['css', 'scss']:
+    for f in in_files:
+        if not __get_ext(f) in ['css', 'scss']:
+            continue
+
         isCSS = True
         combined = "@option compress: no;"
-
-
     
 
     for f in in_files:
